@@ -34,9 +34,12 @@ namespace NETGeographicLib
    * - WMM2010:
    *   - http://ngdc.noaa.gov/geomag/WMM/DoDWMM.shtml
    *   - http://ngdc.noaa.gov/geomag/WMM/data/WMM2010/WMM2010COF.zip
-   * - WMM2015:
+   * - WMM2015 (deprecated):
    *   - http://ngdc.noaa.gov/geomag/WMM/DoDWMM.shtml
    *   - http://ngdc.noaa.gov/geomag/WMM/data/WMM2015/WMM2015COF.zip
+   * - WMM2015v2:
+   *   - http://ngdc.noaa.gov/geomag/WMM/DoDWMM.shtml
+   *   - http://ngdc.noaa.gov/geomag/WMM/data/WMM2015/WMM2015v2COF.zip
    * - IGRF11:
    *   - http://ngdc.noaa.gov/IAGA/vmod/igrf.html
    *   - http://ngdc.noaa.gov/IAGA/vmod/igrf11coeffs.txt
@@ -58,7 +61,7 @@ namespace NETGeographicLib
    * The following functions are implemented as properties:
    * Description, DateTime, MagneticFile, MagneticModelName,
    * MagneticModelDirectory, MinHeight, MaxHeight, MinTime, MaxTime,
-   * MajorRadius, and Flattening.
+   * EquatorialRadius, and Flattening.
    **********************************************************************/
     public ref class MagneticModel
     {
@@ -334,7 +337,7 @@ namespace NETGeographicLib
          *   the value of \e a inherited from the Geocentric object used in the
          *   constructor.
          **********************************************************************/
-        property double MajorRadius { double get(); }
+        property double EquatorialRadius { double get(); }
 
         /**
          * @return \e f the flattening of the ellipsoid.  This is the value
@@ -359,7 +362,7 @@ namespace NETGeographicLib
          * @return the default name for the magnetic model.
          *
          * This is the value of the environment variable
-         * GEOGRAPHICLIB_MAGNETIC_NAME, if set, otherwise, it is "wmm2015".
+         * GEOGRAPHICLIB_MAGNETIC_NAME, if set, otherwise, it is "wmm2015v2".
          * The MagneticModel class does not use this function; it is just
          * provided as a convenience for a calling program when constructing a
          * MagneticModel object.
